'''_602.py

PlungeShaverInputsAndMicroGeometry
'''


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.gears.manufacturing.cylindrical.plunge_shaving import _598, _597, _605
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_PLUNGE_SHAVER_INPUTS_AND_MICRO_GEOMETRY = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.PlungeShaving', 'PlungeShaverInputsAndMicroGeometry')


__docformat__ = 'restructuredtext en'
__all__ = ('PlungeShaverInputsAndMicroGeometry',)


class PlungeShaverInputsAndMicroGeometry(_0.APIBase):
    '''PlungeShaverInputsAndMicroGeometry

    This is a mastapy class.
    '''

    TYPE = _PLUNGE_SHAVER_INPUTS_AND_MICRO_GEOMETRY

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlungeShaverInputsAndMicroGeometry.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def do_both_flanks_have_the_same_micro_geometry(self) -> 'bool':
        '''bool: 'DoBothFlanksHaveTheSameMicroGeometry' is the original name of this property.'''

        return self.wrapped.DoBothFlanksHaveTheSameMicroGeometry

    @do_both_flanks_have_the_same_micro_geometry.setter
    def do_both_flanks_have_the_same_micro_geometry(self, value: 'bool'):
        self.wrapped.DoBothFlanksHaveTheSameMicroGeometry = bool(value) if value else False

    @property
    def micro_geometry_source(self) -> 'enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionType':
        '''enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionType: 'MicroGeometrySource' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionType.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.MicroGeometrySource, value) if self.wrapped.MicroGeometrySource else None

    @micro_geometry_source.setter
    def micro_geometry_source(self, value: 'enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionType.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionType.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.MicroGeometrySource = value

    @property
    def profile_measurement_method(self) -> 'enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod':
        '''enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod: 'ProfileMeasurementMethod' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.ProfileMeasurementMethod, value) if self.wrapped.ProfileMeasurementMethod else None

    @profile_measurement_method.setter
    def profile_measurement_method(self, value: 'enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.ProfileMeasurementMethod = value

    @property
    def lead_measurement_method(self) -> 'enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod':
        '''enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod: 'LeadMeasurementMethod' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod.wrapped_type()
        return enum_with_selected_value_runtime.create(self.wrapped.LeadMeasurementMethod, value) if self.wrapped.LeadMeasurementMethod else None

    @lead_measurement_method.setter
    def lead_measurement_method(self, value: 'enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_MicroGeometryDefinitionMethod.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.LeadMeasurementMethod = value

    @property
    def number_of_points_of_interest(self) -> 'int':
        '''int: 'NumberOfPointsOfInterest' is the original name of this property.'''

        return self.wrapped.NumberOfPointsOfInterest

    @number_of_points_of_interest.setter
    def number_of_points_of_interest(self, value: 'int'):
        self.wrapped.NumberOfPointsOfInterest = int(value) if value else 0

    @property
    def points_of_interest_left_flank(self) -> 'List[_605.PointOfInterest]':
        '''List[PointOfInterest]: 'PointsOfInterestLeftFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PointsOfInterestLeftFlank, constructor.new(_605.PointOfInterest))
        return value

    @property
    def points_of_interest_right_flank(self) -> 'List[_605.PointOfInterest]':
        '''List[PointOfInterest]: 'PointsOfInterestRightFlank' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.PointsOfInterestRightFlank, constructor.new(_605.PointOfInterest))
        return value

    @property
    def report_names(self) -> 'List[str]':
        '''List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ReportNames, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        ''' 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else None)

    def get_default_report_with_encoded_images(self) -> 'str':
        ''' 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        ''' 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else None)

    def output_active_report_as_text_to(self, file_path: 'str'):
        ''' 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else None)

    def get_active_report_with_encoded_images(self) -> 'str':
        ''' 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else None, file_path if file_path else None)

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        ''' 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        '''

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else None)
        return method_result



'''_817.py

WormGearLoadCase
'''


from mastapy.gears.load_case import _814
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_LOAD_CASE = python_net_import('SMT.MastaAPI.Gears.LoadCase.Worm', 'WormGearLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearLoadCase',)


class WormGearLoadCase(_814.GearLoadCaseBase):
    '''WormGearLoadCase

    This is a mastapy class.
    '''

    TYPE = _WORM_GEAR_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGearLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1876.py

NonBarrelRollerBearing
'''


from typing import List

from mastapy.bearings.bearing_designs.rolling import _1878, _1879, _1877
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal.python_net import python_net_import

_NON_BARREL_ROLLER_BEARING = python_net_import('SMT.MastaAPI.Bearings.BearingDesigns.Rolling', 'NonBarrelRollerBearing')


__docformat__ = 'restructuredtext en'
__all__ = ('NonBarrelRollerBearing',)


class NonBarrelRollerBearing(_1877.RollerBearing):
    '''NonBarrelRollerBearing

    This is a mastapy class.
    '''

    TYPE = _NON_BARREL_ROLLER_BEARING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'NonBarrelRollerBearing.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def roller_end_shape(self) -> '_1878.RollerEndShape':
        '''RollerEndShape: 'RollerEndShape' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.RollerEndShape)
        return constructor.new(_1878.RollerEndShape)(value) if value else None

    @roller_end_shape.setter
    def roller_end_shape(self, value: '_1878.RollerEndShape'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.RollerEndShape = value

    @property
    def roller_end_radius(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'RollerEndRadius' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.RollerEndRadius) if self.wrapped.RollerEndRadius else None

    @roller_end_radius.setter
    def roller_end_radius(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.RollerEndRadius = value

    @property
    def ribs(self) -> 'List[_1879.RollerRibDetail]':
        '''List[RollerRibDetail]: 'Ribs' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Ribs, constructor.new(_1879.RollerRibDetail))
        return value



'''_6570.py

FlexiblePinAssemblyLoadCase
'''


from mastapy.utility import _1367
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy.system_model.part_model import _2162
from mastapy.system_model.analyses_and_results.static_loads import _6637
from mastapy._internal.python_net import python_net_import

_FLEXIBLE_PIN_ASSEMBLY_LOAD_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'FlexiblePinAssemblyLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('FlexiblePinAssemblyLoadCase',)


class FlexiblePinAssemblyLoadCase(_6637.SpecialisedAssemblyLoadCase):
    '''FlexiblePinAssemblyLoadCase

    This is a mastapy class.
    '''

    TYPE = _FLEXIBLE_PIN_ASSEMBLY_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FlexiblePinAssemblyLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def include_inner_race_distortion_for_flexible_pin_spindle(self) -> '_1367.LoadCaseOverrideOption':
        '''LoadCaseOverrideOption: 'IncludeInnerRaceDistortionForFlexiblePinSpindle' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.IncludeInnerRaceDistortionForFlexiblePinSpindle)
        return constructor.new(_1367.LoadCaseOverrideOption)(value) if value else None

    @include_inner_race_distortion_for_flexible_pin_spindle.setter
    def include_inner_race_distortion_for_flexible_pin_spindle(self, value: '_1367.LoadCaseOverrideOption'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.IncludeInnerRaceDistortionForFlexiblePinSpindle = value

    @property
    def assembly_design(self) -> '_2162.FlexiblePinAssembly':
        '''FlexiblePinAssembly: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2162.FlexiblePinAssembly)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6225 import AbstractAssemblyCriticalSpeedAnalysis
    from ._6226 import AbstractShaftCriticalSpeedAnalysis
    from ._6227 import AbstractShaftOrHousingCriticalSpeedAnalysis
    from ._6228 import AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis
    from ._6229 import AGMAGleasonConicalGearCriticalSpeedAnalysis
    from ._6230 import AGMAGleasonConicalGearMeshCriticalSpeedAnalysis
    from ._6231 import AGMAGleasonConicalGearSetCriticalSpeedAnalysis
    from ._6232 import AssemblyCriticalSpeedAnalysis
    from ._6233 import BearingCriticalSpeedAnalysis
    from ._6234 import BeltConnectionCriticalSpeedAnalysis
    from ._6235 import BeltDriveCriticalSpeedAnalysis
    from ._6236 import BevelDifferentialGearCriticalSpeedAnalysis
    from ._6237 import BevelDifferentialGearMeshCriticalSpeedAnalysis
    from ._6238 import BevelDifferentialGearSetCriticalSpeedAnalysis
    from ._6239 import BevelDifferentialPlanetGearCriticalSpeedAnalysis
    from ._6240 import BevelDifferentialSunGearCriticalSpeedAnalysis
    from ._6241 import BevelGearCriticalSpeedAnalysis
    from ._6242 import BevelGearMeshCriticalSpeedAnalysis
    from ._6243 import BevelGearSetCriticalSpeedAnalysis
    from ._6244 import BoltCriticalSpeedAnalysis
    from ._6245 import BoltedJointCriticalSpeedAnalysis
    from ._6246 import ClutchConnectionCriticalSpeedAnalysis
    from ._6247 import ClutchCriticalSpeedAnalysis
    from ._6248 import ClutchHalfCriticalSpeedAnalysis
    from ._6249 import CoaxialConnectionCriticalSpeedAnalysis
    from ._6250 import ComponentCriticalSpeedAnalysis
    from ._6251 import ConceptCouplingConnectionCriticalSpeedAnalysis
    from ._6252 import ConceptCouplingCriticalSpeedAnalysis
    from ._6253 import ConceptCouplingHalfCriticalSpeedAnalysis
    from ._6254 import ConceptGearCriticalSpeedAnalysis
    from ._6255 import ConceptGearMeshCriticalSpeedAnalysis
    from ._6256 import ConceptGearSetCriticalSpeedAnalysis
    from ._6257 import ConicalGearCriticalSpeedAnalysis
    from ._6258 import ConicalGearMeshCriticalSpeedAnalysis
    from ._6259 import ConicalGearSetCriticalSpeedAnalysis
    from ._6260 import ConnectionCriticalSpeedAnalysis
    from ._6261 import ConnectorCriticalSpeedAnalysis
    from ._6262 import CouplingConnectionCriticalSpeedAnalysis
    from ._6263 import CouplingCriticalSpeedAnalysis
    from ._6264 import CouplingHalfCriticalSpeedAnalysis
    from ._2332 import CriticalSpeedAnalysis
    from ._6265 import CriticalSpeedAnalysisDrawStyle
    from ._6266 import CriticalSpeedAnalysisOptions
    from ._6267 import CVTBeltConnectionCriticalSpeedAnalysis
    from ._6268 import CVTCriticalSpeedAnalysis
    from ._6269 import CVTPulleyCriticalSpeedAnalysis
    from ._6270 import CycloidalAssemblyCriticalSpeedAnalysis
    from ._6271 import CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis
    from ._6272 import CycloidalDiscCriticalSpeedAnalysis
    from ._6273 import CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis
    from ._6274 import CylindricalGearCriticalSpeedAnalysis
    from ._6275 import CylindricalGearMeshCriticalSpeedAnalysis
    from ._6276 import CylindricalGearSetCriticalSpeedAnalysis
    from ._6277 import CylindricalPlanetGearCriticalSpeedAnalysis
    from ._6278 import DatumCriticalSpeedAnalysis
    from ._6279 import ExternalCADModelCriticalSpeedAnalysis
    from ._6280 import FaceGearCriticalSpeedAnalysis
    from ._6281 import FaceGearMeshCriticalSpeedAnalysis
    from ._6282 import FaceGearSetCriticalSpeedAnalysis
    from ._6283 import FEPartCriticalSpeedAnalysis
    from ._6284 import FlexiblePinAssemblyCriticalSpeedAnalysis
    from ._6285 import GearCriticalSpeedAnalysis
    from ._6286 import GearMeshCriticalSpeedAnalysis
    from ._6287 import GearSetCriticalSpeedAnalysis
    from ._6288 import GuideDxfModelCriticalSpeedAnalysis
    from ._6289 import HypoidGearCriticalSpeedAnalysis
    from ._6290 import HypoidGearMeshCriticalSpeedAnalysis
    from ._6291 import HypoidGearSetCriticalSpeedAnalysis
    from ._6292 import InterMountableComponentConnectionCriticalSpeedAnalysis
    from ._6293 import KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis
    from ._6294 import KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis
    from ._6295 import KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis
    from ._6296 import KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis
    from ._6297 import KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis
    from ._6298 import KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis
    from ._6299 import KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis
    from ._6300 import KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis
    from ._6301 import KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis
    from ._6302 import MassDiscCriticalSpeedAnalysis
    from ._6303 import MeasurementComponentCriticalSpeedAnalysis
    from ._6304 import MountableComponentCriticalSpeedAnalysis
    from ._6305 import OilSealCriticalSpeedAnalysis
    from ._6306 import PartCriticalSpeedAnalysis
    from ._6307 import PartToPartShearCouplingConnectionCriticalSpeedAnalysis
    from ._6308 import PartToPartShearCouplingCriticalSpeedAnalysis
    from ._6309 import PartToPartShearCouplingHalfCriticalSpeedAnalysis
    from ._6310 import PlanetaryConnectionCriticalSpeedAnalysis
    from ._6311 import PlanetaryGearSetCriticalSpeedAnalysis
    from ._6312 import PlanetCarrierCriticalSpeedAnalysis
    from ._6313 import PointLoadCriticalSpeedAnalysis
    from ._6314 import PowerLoadCriticalSpeedAnalysis
    from ._6315 import PulleyCriticalSpeedAnalysis
    from ._6316 import RingPinsCriticalSpeedAnalysis
    from ._6317 import RingPinsToDiscConnectionCriticalSpeedAnalysis
    from ._6318 import RollingRingAssemblyCriticalSpeedAnalysis
    from ._6319 import RollingRingConnectionCriticalSpeedAnalysis
    from ._6320 import RollingRingCriticalSpeedAnalysis
    from ._6321 import RootAssemblyCriticalSpeedAnalysis
    from ._6322 import ShaftCriticalSpeedAnalysis
    from ._6323 import ShaftHubConnectionCriticalSpeedAnalysis
    from ._6324 import ShaftToMountableComponentConnectionCriticalSpeedAnalysis
    from ._6325 import SpecialisedAssemblyCriticalSpeedAnalysis
    from ._6326 import SpiralBevelGearCriticalSpeedAnalysis
    from ._6327 import SpiralBevelGearMeshCriticalSpeedAnalysis
    from ._6328 import SpiralBevelGearSetCriticalSpeedAnalysis
    from ._6329 import SpringDamperConnectionCriticalSpeedAnalysis
    from ._6330 import SpringDamperCriticalSpeedAnalysis
    from ._6331 import SpringDamperHalfCriticalSpeedAnalysis
    from ._6332 import StraightBevelDiffGearCriticalSpeedAnalysis
    from ._6333 import StraightBevelDiffGearMeshCriticalSpeedAnalysis
    from ._6334 import StraightBevelDiffGearSetCriticalSpeedAnalysis
    from ._6335 import StraightBevelGearCriticalSpeedAnalysis
    from ._6336 import StraightBevelGearMeshCriticalSpeedAnalysis
    from ._6337 import StraightBevelGearSetCriticalSpeedAnalysis
    from ._6338 import StraightBevelPlanetGearCriticalSpeedAnalysis
    from ._6339 import StraightBevelSunGearCriticalSpeedAnalysis
    from ._6340 import SynchroniserCriticalSpeedAnalysis
    from ._6341 import SynchroniserHalfCriticalSpeedAnalysis
    from ._6342 import SynchroniserPartCriticalSpeedAnalysis
    from ._6343 import SynchroniserSleeveCriticalSpeedAnalysis
    from ._6344 import TorqueConverterConnectionCriticalSpeedAnalysis
    from ._6345 import TorqueConverterCriticalSpeedAnalysis
    from ._6346 import TorqueConverterPumpCriticalSpeedAnalysis
    from ._6347 import TorqueConverterTurbineCriticalSpeedAnalysis
    from ._6348 import UnbalancedMassCriticalSpeedAnalysis
    from ._6349 import VirtualComponentCriticalSpeedAnalysis
    from ._6350 import WormGearCriticalSpeedAnalysis
    from ._6351 import WormGearMeshCriticalSpeedAnalysis
    from ._6352 import WormGearSetCriticalSpeedAnalysis
    from ._6353 import ZerolBevelGearCriticalSpeedAnalysis
    from ._6354 import ZerolBevelGearMeshCriticalSpeedAnalysis
    from ._6355 import ZerolBevelGearSetCriticalSpeedAnalysis



'''_6484.py

ZerolBevelGearSetCompoundCriticalSpeedAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2261
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.critical_speed_analyses.compound import _6482, _6483, _6374
from mastapy.system_model.analyses_and_results.critical_speed_analyses import _6355
from mastapy._internal.python_net import python_net_import

_ZEROL_BEVEL_GEAR_SET_COMPOUND_CRITICAL_SPEED_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.CriticalSpeedAnalyses.Compound', 'ZerolBevelGearSetCompoundCriticalSpeedAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ZerolBevelGearSetCompoundCriticalSpeedAnalysis',)


class ZerolBevelGearSetCompoundCriticalSpeedAnalysis(_6374.BevelGearSetCompoundCriticalSpeedAnalysis):
    '''ZerolBevelGearSetCompoundCriticalSpeedAnalysis

    This is a mastapy class.
    '''

    TYPE = _ZEROL_BEVEL_GEAR_SET_COMPOUND_CRITICAL_SPEED_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ZerolBevelGearSetCompoundCriticalSpeedAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2261.ZerolBevelGearSet':
        '''ZerolBevelGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2261.ZerolBevelGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2261.ZerolBevelGearSet':
        '''ZerolBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2261.ZerolBevelGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def zerol_bevel_gears_compound_critical_speed_analysis(self) -> 'List[_6482.ZerolBevelGearCompoundCriticalSpeedAnalysis]':
        '''List[ZerolBevelGearCompoundCriticalSpeedAnalysis]: 'ZerolBevelGearsCompoundCriticalSpeedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ZerolBevelGearsCompoundCriticalSpeedAnalysis, constructor.new(_6482.ZerolBevelGearCompoundCriticalSpeedAnalysis))
        return value

    @property
    def zerol_bevel_meshes_compound_critical_speed_analysis(self) -> 'List[_6483.ZerolBevelGearMeshCompoundCriticalSpeedAnalysis]':
        '''List[ZerolBevelGearMeshCompoundCriticalSpeedAnalysis]: 'ZerolBevelMeshesCompoundCriticalSpeedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ZerolBevelMeshesCompoundCriticalSpeedAnalysis, constructor.new(_6483.ZerolBevelGearMeshCompoundCriticalSpeedAnalysis))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_6355.ZerolBevelGearSetCriticalSpeedAnalysis]':
        '''List[ZerolBevelGearSetCriticalSpeedAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_6355.ZerolBevelGearSetCriticalSpeedAnalysis))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_6355.ZerolBevelGearSetCriticalSpeedAnalysis]':
        '''List[ZerolBevelGearSetCriticalSpeedAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_6355.ZerolBevelGearSetCriticalSpeedAnalysis))
        return value



'''_2385.py

CompoundSteadyStateSynchronousResponseAnalysis
'''


from mastapy.system_model.analyses_and_results import _2326
from mastapy._internal.python_net import python_net_import

_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults', 'CompoundSteadyStateSynchronousResponseAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('CompoundSteadyStateSynchronousResponseAnalysis',)


class CompoundSteadyStateSynchronousResponseAnalysis(_2326.CompoundAnalysis):
    '''CompoundSteadyStateSynchronousResponseAnalysis

    This is a mastapy class.
    '''

    TYPE = _COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CompoundSteadyStateSynchronousResponseAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_4567.py

CouplingHalfModalAnalysisAtASpeed
'''


from mastapy.system_model.part_model.couplings import (
    _2291, _2286, _2289, _2294,
    _2296, _2297, _2303, _2308,
    _2311, _2312, _2313, _2315,
    _2317
)
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed import _4606
from mastapy._internal.python_net import python_net_import

_COUPLING_HALF_MODAL_ANALYSIS_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtASpeed', 'CouplingHalfModalAnalysisAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('CouplingHalfModalAnalysisAtASpeed',)


class CouplingHalfModalAnalysisAtASpeed(_4606.MountableComponentModalAnalysisAtASpeed):
    '''CouplingHalfModalAnalysisAtASpeed

    This is a mastapy class.
    '''

    TYPE = _COUPLING_HALF_MODAL_ANALYSIS_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CouplingHalfModalAnalysisAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2291.CouplingHalf':
        '''CouplingHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2291.CouplingHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to CouplingHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_clutch_half(self) -> '_2286.ClutchHalf':
        '''ClutchHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2286.ClutchHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to ClutchHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_concept_coupling_half(self) -> '_2289.ConceptCouplingHalf':
        '''ConceptCouplingHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2289.ConceptCouplingHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to ConceptCouplingHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_cvt_pulley(self) -> '_2294.CVTPulley':
        '''CVTPulley: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2294.CVTPulley.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to CVTPulley. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_part_to_part_shear_coupling_half(self) -> '_2296.PartToPartShearCouplingHalf':
        '''PartToPartShearCouplingHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2296.PartToPartShearCouplingHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to PartToPartShearCouplingHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_pulley(self) -> '_2297.Pulley':
        '''Pulley: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2297.Pulley.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to Pulley. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_rolling_ring(self) -> '_2303.RollingRing':
        '''RollingRing: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2303.RollingRing.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to RollingRing. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_spring_damper_half(self) -> '_2308.SpringDamperHalf':
        '''SpringDamperHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2308.SpringDamperHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to SpringDamperHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_synchroniser_half(self) -> '_2311.SynchroniserHalf':
        '''SynchroniserHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2311.SynchroniserHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to SynchroniserHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_synchroniser_part(self) -> '_2312.SynchroniserPart':
        '''SynchroniserPart: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2312.SynchroniserPart.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to SynchroniserPart. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_synchroniser_sleeve(self) -> '_2313.SynchroniserSleeve':
        '''SynchroniserSleeve: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2313.SynchroniserSleeve.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to SynchroniserSleeve. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_torque_converter_pump(self) -> '_2315.TorqueConverterPump':
        '''TorqueConverterPump: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2315.TorqueConverterPump.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to TorqueConverterPump. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_torque_converter_turbine(self) -> '_2317.TorqueConverterTurbine':
        '''TorqueConverterTurbine: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2317.TorqueConverterTurbine.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to TorqueConverterTurbine. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None



'''_2221.py

AGMAGleasonConicalGearSet
'''


from mastapy.system_model.part_model.gears import _2231
from mastapy._internal.python_net import python_net_import

_AGMA_GLEASON_CONICAL_GEAR_SET = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Gears', 'AGMAGleasonConicalGearSet')


__docformat__ = 'restructuredtext en'
__all__ = ('AGMAGleasonConicalGearSet',)


class AGMAGleasonConicalGearSet(_2231.ConicalGearSet):
    '''AGMAGleasonConicalGearSet

    This is a mastapy class.
    '''

    TYPE = _AGMA_GLEASON_CONICAL_GEAR_SET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'AGMAGleasonConicalGearSet.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_6877.py

ExternalCADModelCompoundAdvancedTimeSteppingAnalysisForModulation
'''


from typing import List

from mastapy.system_model.part_model import _2160
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import _6747
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation.compound import _6850
from mastapy._internal.python_net import python_net_import

_EXTERNAL_CAD_MODEL_COMPOUND_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation.Compound', 'ExternalCADModelCompoundAdvancedTimeSteppingAnalysisForModulation')


__docformat__ = 'restructuredtext en'
__all__ = ('ExternalCADModelCompoundAdvancedTimeSteppingAnalysisForModulation',)


class ExternalCADModelCompoundAdvancedTimeSteppingAnalysisForModulation(_6850.ComponentCompoundAdvancedTimeSteppingAnalysisForModulation):
    '''ExternalCADModelCompoundAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    '''

    TYPE = _EXTERNAL_CAD_MODEL_COMPOUND_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ExternalCADModelCompoundAdvancedTimeSteppingAnalysisForModulation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2160.ExternalCADModel':
        '''ExternalCADModel: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2160.ExternalCADModel)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_analysis_cases_ready(self) -> 'List[_6747.ExternalCADModelAdvancedTimeSteppingAnalysisForModulation]':
        '''List[ExternalCADModelAdvancedTimeSteppingAnalysisForModulation]: 'ComponentAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCasesReady, constructor.new(_6747.ExternalCADModelAdvancedTimeSteppingAnalysisForModulation))
        return value

    @property
    def component_analysis_cases(self) -> 'List[_6747.ExternalCADModelAdvancedTimeSteppingAnalysisForModulation]':
        '''List[ExternalCADModelAdvancedTimeSteppingAnalysisForModulation]: 'ComponentAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAnalysisCases, constructor.new(_6747.ExternalCADModelAdvancedTimeSteppingAnalysisForModulation))
        return value



'''_5549.py

CylindricalGearSetCompoundHarmonicAnalysisOfSingleExcitation
'''


from typing import List

from mastapy.system_model.part_model.gears import _2233, _2249
from mastapy._internal import constructor, conversion
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation.compound import _5547, _5548, _5560
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation import _5419
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_SET_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation.Compound', 'CylindricalGearSetCompoundHarmonicAnalysisOfSingleExcitation')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearSetCompoundHarmonicAnalysisOfSingleExcitation',)


class CylindricalGearSetCompoundHarmonicAnalysisOfSingleExcitation(_5560.GearSetCompoundHarmonicAnalysisOfSingleExcitation):
    '''CylindricalGearSetCompoundHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_SET_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearSetCompoundHarmonicAnalysisOfSingleExcitation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2233.CylindricalGearSet':
        '''CylindricalGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2233.CylindricalGearSet.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to CylindricalGearSet. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ComponentDesign.__class__)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2233.CylindricalGearSet':
        '''CylindricalGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2233.CylindricalGearSet.TYPE not in self.wrapped.AssemblyDesign.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to CylindricalGearSet. Expected: {}.'.format(self.wrapped.AssemblyDesign.__class__.__qualname__))

        return constructor.new_override(self.wrapped.AssemblyDesign.__class__)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def cylindrical_gears_compound_harmonic_analysis_of_single_excitation(self) -> 'List[_5547.CylindricalGearCompoundHarmonicAnalysisOfSingleExcitation]':
        '''List[CylindricalGearCompoundHarmonicAnalysisOfSingleExcitation]: 'CylindricalGearsCompoundHarmonicAnalysisOfSingleExcitation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalGearsCompoundHarmonicAnalysisOfSingleExcitation, constructor.new(_5547.CylindricalGearCompoundHarmonicAnalysisOfSingleExcitation))
        return value

    @property
    def cylindrical_meshes_compound_harmonic_analysis_of_single_excitation(self) -> 'List[_5548.CylindricalGearMeshCompoundHarmonicAnalysisOfSingleExcitation]':
        '''List[CylindricalGearMeshCompoundHarmonicAnalysisOfSingleExcitation]: 'CylindricalMeshesCompoundHarmonicAnalysisOfSingleExcitation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalMeshesCompoundHarmonicAnalysisOfSingleExcitation, constructor.new(_5548.CylindricalGearMeshCompoundHarmonicAnalysisOfSingleExcitation))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5419.CylindricalGearSetHarmonicAnalysisOfSingleExcitation]':
        '''List[CylindricalGearSetHarmonicAnalysisOfSingleExcitation]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_5419.CylindricalGearSetHarmonicAnalysisOfSingleExcitation))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5419.CylindricalGearSetHarmonicAnalysisOfSingleExcitation]':
        '''List[CylindricalGearSetHarmonicAnalysisOfSingleExcitation]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_5419.CylindricalGearSetHarmonicAnalysisOfSingleExcitation))
        return value



'''_42.py

SurfaceFinishes
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_SURFACE_FINISHES = python_net_import('SMT.MastaAPI.Shafts', 'SurfaceFinishes')


__docformat__ = 'restructuredtext en'
__all__ = ('SurfaceFinishes',)


class SurfaceFinishes(Enum):
    '''SurfaceFinishes

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _SURFACE_FINISHES

    __hash__ = None

    HIGHLY_POLISHED_NOMINAL = 0
    POLISHED = 1
    GROUND = 2
    COLD_DRAWN_OR_MACHINED_63µIN_16µM = 3
    COLD_DRAWN_OR_MACHINED_125µIN_32µM = 4
    COLD_DRAWN_OR_MACHINED_250µIN_63µM = 5
    COLD_DRAWN_OR_MACHINED_500µIN_125µM = 6
    HOT_ROLLED = 7
    FORGED = 8
    USERSPECIFIED = 9


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


SurfaceFinishes.__setattr__ = __enum_setattr
SurfaceFinishes.__delattr__ = __enum_delattr



'''_1371.py

ProgramSettings
'''


from mastapy._internal import constructor
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.utility import _1369
from mastapy._internal.python_net import python_net_import

_PROGRAM_SETTINGS = python_net_import('SMT.MastaAPI.Utility', 'ProgramSettings')


__docformat__ = 'restructuredtext en'
__all__ = ('ProgramSettings',)


class ProgramSettings(_1369.PerMachineSettings):
    '''ProgramSettings

    This is a mastapy class.
    '''

    TYPE = _PROGRAM_SETTINGS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ProgramSettings.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def maximum_number_of_undo_items(self) -> 'int':
        '''int: 'MaximumNumberOfUndoItems' is the original name of this property.'''

        return self.wrapped.MaximumNumberOfUndoItems

    @maximum_number_of_undo_items.setter
    def maximum_number_of_undo_items(self, value: 'int'):
        self.wrapped.MaximumNumberOfUndoItems = int(value) if value else 0

    @property
    def number_of_cpu_threads(self) -> 'int':
        '''int: 'NumberOfCPUThreads' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfCPUThreads

    @property
    def number_of_cpu_cores(self) -> 'int':
        '''int: 'NumberOfCPUCores' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfCPUCores

    @property
    def maximum_number_of_threads_for_large_operations(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'MaximumNumberOfThreadsForLargeOperations' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.MaximumNumberOfThreadsForLargeOperations) if self.wrapped.MaximumNumberOfThreadsForLargeOperations else None

    @maximum_number_of_threads_for_large_operations.setter
    def maximum_number_of_threads_for_large_operations(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0, is_overridden)
        self.wrapped.MaximumNumberOfThreadsForLargeOperations = value

    @property
    def maximum_number_of_threads_for_mathematically_intensive_operations(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'MaximumNumberOfThreadsForMathematicallyIntensiveOperations' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.MaximumNumberOfThreadsForMathematicallyIntensiveOperations) if self.wrapped.MaximumNumberOfThreadsForMathematicallyIntensiveOperations else None

    @maximum_number_of_threads_for_mathematically_intensive_operations.setter
    def maximum_number_of_threads_for_mathematically_intensive_operations(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0, is_overridden)
        self.wrapped.MaximumNumberOfThreadsForMathematicallyIntensiveOperations = value

    @property
    def allow_multithreading(self) -> 'bool':
        '''bool: 'AllowMultithreading' is the original name of this property.'''

        return self.wrapped.AllowMultithreading

    @allow_multithreading.setter
    def allow_multithreading(self, value: 'bool'):
        self.wrapped.AllowMultithreading = bool(value) if value else False

    @property
    def use_standard_dialog_for_file_save(self) -> 'bool':
        '''bool: 'UseStandardDialogForFileSave' is the original name of this property.'''

        return self.wrapped.UseStandardDialogForFileSave

    @use_standard_dialog_for_file_save.setter
    def use_standard_dialog_for_file_save(self, value: 'bool'):
        self.wrapped.UseStandardDialogForFileSave = bool(value) if value else False

    @property
    def use_standard_dialog_for_file_open(self) -> 'bool':
        '''bool: 'UseStandardDialogForFileOpen' is the original name of this property.'''

        return self.wrapped.UseStandardDialogForFileOpen

    @use_standard_dialog_for_file_open.setter
    def use_standard_dialog_for_file_open(self, value: 'bool'):
        self.wrapped.UseStandardDialogForFileOpen = bool(value) if value else False

    @property
    def include_overridable_property_source_information(self) -> 'bool':
        '''bool: 'IncludeOverridablePropertySourceInformation' is the original name of this property.'''

        return self.wrapped.IncludeOverridablePropertySourceInformation

    @include_overridable_property_source_information.setter
    def include_overridable_property_source_information(self, value: 'bool'):
        self.wrapped.IncludeOverridablePropertySourceInformation = bool(value) if value else False

    @property
    def autosave_interval_minutes(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'AutosaveIntervalMinutes' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.AutosaveIntervalMinutes) if self.wrapped.AutosaveIntervalMinutes else None

    @autosave_interval_minutes.setter
    def autosave_interval_minutes(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0, is_overridden)
        self.wrapped.AutosaveIntervalMinutes = value

    @property
    def use_default_autosave_directory(self) -> 'bool':
        '''bool: 'UseDefaultAutosaveDirectory' is the original name of this property.'''

        return self.wrapped.UseDefaultAutosaveDirectory

    @use_default_autosave_directory.setter
    def use_default_autosave_directory(self, value: 'bool'):
        self.wrapped.UseDefaultAutosaveDirectory = bool(value) if value else False

    @property
    def user_defined_autosave_directory(self) -> 'str':
        '''str: 'UserDefinedAutosaveDirectory' is the original name of this property.'''

        return self.wrapped.UserDefinedAutosaveDirectory

    @user_defined_autosave_directory.setter
    def user_defined_autosave_directory(self, value: 'str'):
        self.wrapped.UserDefinedAutosaveDirectory = str(value) if value else None

    @property
    def autosave_directory(self) -> 'str':
        '''str: 'AutosaveDirectory' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AutosaveDirectory

    @property
    def use_background_saving(self) -> 'bool':
        '''bool: 'UseBackgroundSaving' is the original name of this property.'''

        return self.wrapped.UseBackgroundSaving

    @use_background_saving.setter
    def use_background_saving(self, value: 'bool'):
        self.wrapped.UseBackgroundSaving = bool(value) if value else False

    @property
    def auto_return_licences_inactivity_interval_minutes(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'AutoReturnLicencesInactivityIntervalMinutes' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.AutoReturnLicencesInactivityIntervalMinutes) if self.wrapped.AutoReturnLicencesInactivityIntervalMinutes else None

    @auto_return_licences_inactivity_interval_minutes.setter
    def auto_return_licences_inactivity_interval_minutes(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0, is_overridden)
        self.wrapped.AutoReturnLicencesInactivityIntervalMinutes = value

    @property
    def maximum_number_of_files_to_store_in_history(self) -> 'int':
        '''int: 'MaximumNumberOfFilesToStoreInHistory' is the original name of this property.'''

        return self.wrapped.MaximumNumberOfFilesToStoreInHistory

    @maximum_number_of_files_to_store_in_history.setter
    def maximum_number_of_files_to_store_in_history(self, value: 'int'):
        self.wrapped.MaximumNumberOfFilesToStoreInHistory = int(value) if value else 0

    @property
    def confirm_exit(self) -> 'bool':
        '''bool: 'ConfirmExit' is the original name of this property.'''

        return self.wrapped.ConfirmExit

    @confirm_exit.setter
    def confirm_exit(self, value: 'bool'):
        self.wrapped.ConfirmExit = bool(value) if value else False

    @property
    def use_compression_for_masta_files(self) -> 'bool':
        '''bool: 'UseCompressionForMASTAFiles' is the original name of this property.'''

        return self.wrapped.UseCompressionForMASTAFiles

    @use_compression_for_masta_files.setter
    def use_compression_for_masta_files(self, value: 'bool'):
        self.wrapped.UseCompressionForMASTAFiles = bool(value) if value else False

    @property
    def font_size(self) -> 'float':
        '''float: 'FontSize' is the original name of this property.'''

        return self.wrapped.FontSize

    @font_size.setter
    def font_size(self, value: 'float'):
        self.wrapped.FontSize = float(value) if value else 0.0

    @property
    def override_font(self) -> 'str':
        '''str: 'OverrideFont' is the original name of this property.'''

        return self.wrapped.OverrideFont

    @override_font.setter
    def override_font(self, value: 'str'):
        self.wrapped.OverrideFont = str(value) if value else None

    @property
    def check_for_new_version_on_startup(self) -> 'bool':
        '''bool: 'CheckForNewVersionOnStartup' is the original name of this property.'''

        return self.wrapped.CheckForNewVersionOnStartup

    @check_for_new_version_on_startup.setter
    def check_for_new_version_on_startup(self, value: 'bool'):
        self.wrapped.CheckForNewVersionOnStartup = bool(value) if value else False

    @property
    def show_number_of_teeth_with_gear_set_names(self) -> 'bool':
        '''bool: 'ShowNumberOfTeethWithGearSetNames' is the original name of this property.'''

        return self.wrapped.ShowNumberOfTeethWithGearSetNames

    @show_number_of_teeth_with_gear_set_names.setter
    def show_number_of_teeth_with_gear_set_names(self, value: 'bool'):
        self.wrapped.ShowNumberOfTeethWithGearSetNames = bool(value) if value else False

    @property
    def show_drawing_numbers_in_tree_view(self) -> 'bool':
        '''bool: 'ShowDrawingNumbersInTreeView' is the original name of this property.'''

        return self.wrapped.ShowDrawingNumbersInTreeView

    @show_drawing_numbers_in_tree_view.setter
    def show_drawing_numbers_in_tree_view(self, value: 'bool'):
        self.wrapped.ShowDrawingNumbersInTreeView = bool(value) if value else False

    @property
    def ask_for_part_names_in_the_2d_view(self) -> 'bool':
        '''bool: 'AskForPartNamesInThe2DView' is the original name of this property.'''

        return self.wrapped.AskForPartNamesInThe2DView

    @ask_for_part_names_in_the_2d_view.setter
    def ask_for_part_names_in_the_2d_view(self, value: 'bool'):
        self.wrapped.AskForPartNamesInThe2DView = bool(value) if value else False

    @property
    def number_of_connections_to_show_when_multi_selecting(self) -> 'int':
        '''int: 'NumberOfConnectionsToShowWhenMultiSelecting' is the original name of this property.'''

        return self.wrapped.NumberOfConnectionsToShowWhenMultiSelecting

    @number_of_connections_to_show_when_multi_selecting.setter
    def number_of_connections_to_show_when_multi_selecting(self, value: 'int'):
        self.wrapped.NumberOfConnectionsToShowWhenMultiSelecting = int(value) if value else 0

    @property
    def show_tutorial_on_startup(self) -> 'bool':
        '''bool: 'ShowTutorialOnStartup' is the original name of this property.'''

        return self.wrapped.ShowTutorialOnStartup

    @show_tutorial_on_startup.setter
    def show_tutorial_on_startup(self, value: 'bool'):
        self.wrapped.ShowTutorialOnStartup = bool(value) if value else False

    @property
    def number_of_days_of_advance_warning_for_expiring_features(self) -> 'int':
        '''int: 'NumberOfDaysOfAdvanceWarningForExpiringFeatures' is the original name of this property.'''

        return self.wrapped.NumberOfDaysOfAdvanceWarningForExpiringFeatures

    @number_of_days_of_advance_warning_for_expiring_features.setter
    def number_of_days_of_advance_warning_for_expiring_features(self, value: 'int'):
        self.wrapped.NumberOfDaysOfAdvanceWarningForExpiringFeatures = int(value) if value else 0

    @property
    def prompt_to_copy_network_executable_directory_locally(self) -> 'bool':
        '''bool: 'PromptToCopyNetworkExecutableDirectoryLocally' is the original name of this property.'''

        return self.wrapped.PromptToCopyNetworkExecutableDirectoryLocally

    @prompt_to_copy_network_executable_directory_locally.setter
    def prompt_to_copy_network_executable_directory_locally(self, value: 'bool'):
        self.wrapped.PromptToCopyNetworkExecutableDirectoryLocally = bool(value) if value else False

    def select_autosave_directory(self):
        ''' 'SelectAutosaveDirectory' is the original name of this method.'''

        self.wrapped.SelectAutosaveDirectory()

    def clear_mru_entries(self):
        ''' 'ClearMRUEntries' is the original name of this method.'''

        self.wrapped.ClearMRUEntries()



'''_1720.py

LoadedBallBearingRaceResults
'''


from mastapy._internal import constructor
from mastapy.bearings.bearing_results.rolling import _1751
from mastapy._internal.python_net import python_net_import

_LOADED_BALL_BEARING_RACE_RESULTS = python_net_import('SMT.MastaAPI.Bearings.BearingResults.Rolling', 'LoadedBallBearingRaceResults')


__docformat__ = 'restructuredtext en'
__all__ = ('LoadedBallBearingRaceResults',)


class LoadedBallBearingRaceResults(_1751.LoadedRollingBearingRaceResults):
    '''LoadedBallBearingRaceResults

    This is a mastapy class.
    '''

    TYPE = _LOADED_BALL_BEARING_RACE_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LoadedBallBearingRaceResults.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def contact_radius_at_right_angles_to_rolling_direction(self) -> 'float':
        '''float: 'ContactRadiusAtRightAnglesToRollingDirection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ContactRadiusAtRightAnglesToRollingDirection

    @property
    def hertzian_semi_minor_dimension_highest_load(self) -> 'float':
        '''float: 'HertzianSemiMinorDimensionHighestLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HertzianSemiMinorDimensionHighestLoad

    @property
    def hertzian_semi_major_dimension_highest_load(self) -> 'float':
        '''float: 'HertzianSemiMajorDimensionHighestLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HertzianSemiMajorDimensionHighestLoad



'''_474.py

ISO63362019GearSingleFlankRating
'''


from mastapy._internal import constructor
from mastapy.gears.rating.cylindrical.iso6336 import _472
from mastapy._internal.python_net import python_net_import

_ISO63362019_GEAR_SINGLE_FLANK_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336', 'ISO63362019GearSingleFlankRating')


__docformat__ = 'restructuredtext en'
__all__ = ('ISO63362019GearSingleFlankRating',)


class ISO63362019GearSingleFlankRating(_472.ISO63362006GearSingleFlankRating):
    '''ISO63362019GearSingleFlankRating

    This is a mastapy class.
    '''

    TYPE = _ISO63362019_GEAR_SINGLE_FLANK_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ISO63362019GearSingleFlankRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def load_distribution_influence_factor(self) -> 'float':
        '''float: 'LoadDistributionInfluenceFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadDistributionInfluenceFactor



'''_2342.py

ModalAnalysis
'''


from mastapy.system_model.analyses_and_results.dynamic_analyses import _2333
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses import _3255
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.stability_analyses import _2337
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import _4322
from mastapy.system_model.analyses_and_results.modal_analyses import _2336, _4868, _4866
from mastapy.system_model.analyses_and_results.harmonic_analyses import _2335
from mastapy.system_model.analyses_and_results.analysis_cases import _7234
from mastapy._internal.python_net import python_net_import

_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses', 'ModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ModalAnalysis',)


class ModalAnalysis(_7234.StaticLoadAnalysisCase):
    '''ModalAnalysis

    This is a mastapy class.
    '''

    TYPE = _MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def modal_analysis_results(self) -> '_2333.DynamicAnalysis':
        '''DynamicAnalysis: 'ModalAnalysisResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2333.DynamicAnalysis.TYPE not in self.wrapped.ModalAnalysisResults.__class__.__mro__:
            raise CastException('Failed to cast modal_analysis_results to DynamicAnalysis. Expected: {}.'.format(self.wrapped.ModalAnalysisResults.__class__.__qualname__))

        return constructor.new_override(self.wrapped.ModalAnalysisResults.__class__)(self.wrapped.ModalAnalysisResults) if self.wrapped.ModalAnalysisResults else None

    @property
    def analysis_settings(self) -> '_4868.ModalAnalysisOptions':
        '''ModalAnalysisOptions: 'AnalysisSettings' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_4868.ModalAnalysisOptions)(self.wrapped.AnalysisSettings) if self.wrapped.AnalysisSettings else None

    @property
    def bar_model_export(self) -> '_4866.ModalAnalysisBarModelFEExportOptions':
        '''ModalAnalysisBarModelFEExportOptions: 'BarModelExport' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_4866.ModalAnalysisBarModelFEExportOptions)(self.wrapped.BarModelExport) if self.wrapped.BarModelExport else None



'''_3311.py

SteadyStateSynchronousResponseOptions
'''


from mastapy._internal import constructor
from mastapy._internal.implicit import list_with_selected_item
from mastapy.system_model.part_model import _2180
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_STEADY_STATE_SYNCHRONOUS_RESPONSE_OPTIONS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses', 'SteadyStateSynchronousResponseOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('SteadyStateSynchronousResponseOptions',)


class SteadyStateSynchronousResponseOptions(_0.APIBase):
    '''SteadyStateSynchronousResponseOptions

    This is a mastapy class.
    '''

    TYPE = _STEADY_STATE_SYNCHRONOUS_RESPONSE_OPTIONS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SteadyStateSynchronousResponseOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def start_speed(self) -> 'float':
        '''float: 'StartSpeed' is the original name of this property.'''

        return self.wrapped.StartSpeed

    @start_speed.setter
    def start_speed(self, value: 'float'):
        self.wrapped.StartSpeed = float(value) if value else 0.0

    @property
    def end_speed(self) -> 'float':
        '''float: 'EndSpeed' is the original name of this property.'''

        return self.wrapped.EndSpeed

    @end_speed.setter
    def end_speed(self, value: 'float'):
        self.wrapped.EndSpeed = float(value) if value else 0.0

    @property
    def number_of_speeds(self) -> 'int':
        '''int: 'NumberOfSpeeds' is the original name of this property.'''

        return self.wrapped.NumberOfSpeeds

    @number_of_speeds.setter
    def number_of_speeds(self, value: 'int'):
        self.wrapped.NumberOfSpeeds = int(value) if value else 0

    @property
    def include_gyroscopic_effects(self) -> 'bool':
        '''bool: 'IncludeGyroscopicEffects' is the original name of this property.'''

        return self.wrapped.IncludeGyroscopicEffects

    @include_gyroscopic_effects.setter
    def include_gyroscopic_effects(self, value: 'bool'):
        self.wrapped.IncludeGyroscopicEffects = bool(value) if value else False

    @property
    def include_damping_effects(self) -> 'bool':
        '''bool: 'IncludeDampingEffects' is the original name of this property.'''

        return self.wrapped.IncludeDampingEffects

    @include_damping_effects.setter
    def include_damping_effects(self, value: 'bool'):
        self.wrapped.IncludeDampingEffects = bool(value) if value else False

    @property
    def reference_power_load(self) -> 'list_with_selected_item.ListWithSelectedItem_PowerLoad':
        '''list_with_selected_item.ListWithSelectedItem_PowerLoad: 'ReferencePowerLoad' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_PowerLoad)(self.wrapped.ReferencePowerLoad) if self.wrapped.ReferencePowerLoad else None

    @reference_power_load.setter
    def reference_power_load(self, value: 'list_with_selected_item.ListWithSelectedItem_PowerLoad.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_PowerLoad.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_PowerLoad.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.ReferencePowerLoad = value

    @property
    def include_unbalanced_effects(self) -> 'bool':
        '''bool: 'IncludeUnbalancedEffects' is the original name of this property.'''

        return self.wrapped.IncludeUnbalancedEffects

    @include_unbalanced_effects.setter
    def include_unbalanced_effects(self, value: 'bool'):
        self.wrapped.IncludeUnbalancedEffects = bool(value) if value else False

    @property
    def include_disk_skew_effects(self) -> 'bool':
        '''bool: 'IncludeDiskSkewEffects' is the original name of this property.'''

        return self.wrapped.IncludeDiskSkewEffects

    @include_disk_skew_effects.setter
    def include_disk_skew_effects(self, value: 'bool'):
        self.wrapped.IncludeDiskSkewEffects = bool(value) if value else False

    @property
    def include_shaft_bow_effects(self) -> 'bool':
        '''bool: 'IncludeShaftBowEffects' is the original name of this property.'''

        return self.wrapped.IncludeShaftBowEffects

    @include_shaft_bow_effects.setter
    def include_shaft_bow_effects(self, value: 'bool'):
        self.wrapped.IncludeShaftBowEffects = bool(value) if value else False



'''_1078.py

SpiralBevelGearSetCreationOptions
'''


from mastapy.gears.gear_designs.creation_options import _1076
from mastapy.gears.gear_designs.spiral_bevel import _909
from mastapy._internal.python_net import python_net_import

_SPIRAL_BEVEL_GEAR_SET_CREATION_OPTIONS = python_net_import('SMT.MastaAPI.Gears.GearDesigns.CreationOptions', 'SpiralBevelGearSetCreationOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('SpiralBevelGearSetCreationOptions',)


class SpiralBevelGearSetCreationOptions(_1076.GearSetCreationOptions['_909.SpiralBevelGearSetDesign']):
    '''SpiralBevelGearSetCreationOptions

    This is a mastapy class.
    '''

    TYPE = _SPIRAL_BEVEL_GEAR_SET_CREATION_OPTIONS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpiralBevelGearSetCreationOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_3571.py

StabilityAnalysisDrawStyle
'''


from mastapy.system_model.analyses_and_results.rotor_dynamics import _3726
from mastapy._internal.python_net import python_net_import

_STABILITY_ANALYSIS_DRAW_STYLE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses', 'StabilityAnalysisDrawStyle')


__docformat__ = 'restructuredtext en'
__all__ = ('StabilityAnalysisDrawStyle',)


class StabilityAnalysisDrawStyle(_3726.RotorDynamicsDrawStyle):
    '''StabilityAnalysisDrawStyle

    This is a mastapy class.
    '''

    TYPE = _STABILITY_ANALYSIS_DRAW_STYLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StabilityAnalysisDrawStyle.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_923.py

HypoidGearDesign
'''


from mastapy._internal import constructor
from mastapy.gears.gear_designs.agma_gleason_conical import _1122
from mastapy._internal.python_net import python_net_import

_HYPOID_GEAR_DESIGN = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Hypoid', 'HypoidGearDesign')


__docformat__ = 'restructuredtext en'
__all__ = ('HypoidGearDesign',)


class HypoidGearDesign(_1122.AGMAGleasonConicalGearDesign):
    '''HypoidGearDesign

    This is a mastapy class.
    '''

    TYPE = _HYPOID_GEAR_DESIGN

    __hash__ = None

    def __init__(self, instance_to_wrap: 'HypoidGearDesign.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def face_width(self) -> 'float':
        '''float: 'FaceWidth' is the original name of this property.'''

        return self.wrapped.FaceWidth

    @face_width.setter
    def face_width(self, value: 'float'):
        self.wrapped.FaceWidth = float(value) if value else 0.0

    @property
    def mean_pitch_diameter(self) -> 'float':
        '''float: 'MeanPitchDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanPitchDiameter

    @property
    def addendum_angle(self) -> 'float':
        '''float: 'AddendumAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AddendumAngle

    @property
    def dedendum_angle(self) -> 'float':
        '''float: 'DedendumAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DedendumAngle

    @property
    def outer_tip_diameter(self) -> 'float':
        '''float: 'OuterTipDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OuterTipDiameter

    @property
    def pitch_apex_to_crown(self) -> 'float':
        '''float: 'PitchApexToCrown' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PitchApexToCrown

    @property
    def pitch_angle(self) -> 'float':
        '''float: 'PitchAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PitchAngle

    @property
    def face_angle(self) -> 'float':
        '''float: 'FaceAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FaceAngle

    @property
    def mean_spiral_angle(self) -> 'float':
        '''float: 'MeanSpiralAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanSpiralAngle

    @property
    def pitch_diameter(self) -> 'float':
        '''float: 'PitchDiameter' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PitchDiameter

    @property
    def addendum(self) -> 'float':
        '''float: 'Addendum' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Addendum

    @property
    def dedendum(self) -> 'float':
        '''float: 'Dedendum' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Dedendum

    @property
    def mean_addendum(self) -> 'float':
        '''float: 'MeanAddendum' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanAddendum

    @property
    def mean_dedendum(self) -> 'float':
        '''float: 'MeanDedendum' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanDedendum

    @property
    def mean_radius(self) -> 'float':
        '''float: 'MeanRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanRadius

    @property
    def offset_angle_in_axial_plane(self) -> 'float':
        '''float: 'OffsetAngleInAxialPlane' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OffsetAngleInAxialPlane

    @property
    def crown_to_crossing_point(self) -> 'float':
        '''float: 'CrownToCrossingPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CrownToCrossingPoint

    @property
    def front_crown_to_crossing_point(self) -> 'float':
        '''float: 'FrontCrownToCrossingPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FrontCrownToCrossingPoint

    @property
    def mean_point_to_crossing_point(self) -> 'float':
        '''float: 'MeanPointToCrossingPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanPointToCrossingPoint

    @property
    def pitch_apex_to_crossing_point(self) -> 'float':
        '''float: 'PitchApexToCrossingPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PitchApexToCrossingPoint

    @property
    def root_apex_to_crossing_point(self) -> 'float':
        '''float: 'RootApexToCrossingPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RootApexToCrossingPoint

    @property
    def face_apex_to_crossing_point(self) -> 'float':
        '''float: 'FaceApexToCrossingPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FaceApexToCrossingPoint

    @property
    def outer_cone_distance(self) -> 'float':
        '''float: 'OuterConeDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OuterConeDistance

    @property
    def mean_cone_distance(self) -> 'float':
        '''float: 'MeanConeDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanConeDistance

    @property
    def inner_cone_distance(self) -> 'float':
        '''float: 'InnerConeDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InnerConeDistance

    @property
    def mean_root_spiral_angle(self) -> 'float':
        '''float: 'MeanRootSpiralAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanRootSpiralAngle

    @property
    def mean_normal_circular_thickness(self) -> 'float':
        '''float: 'MeanNormalCircularThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanNormalCircularThickness

    @property
    def outer_whole_depth(self) -> 'float':
        '''float: 'OuterWholeDepth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OuterWholeDepth

    @property
    def outer_working_depth(self) -> 'float':
        '''float: 'OuterWorkingDepth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OuterWorkingDepth

    @property
    def mean_normal_topland(self) -> 'float':
        '''float: 'MeanNormalTopland' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanNormalTopland

    @property
    def geometry_factor_j(self) -> 'float':
        '''float: 'GeometryFactorJ' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.GeometryFactorJ

    @property
    def strength_factor_q(self) -> 'float':
        '''float: 'StrengthFactorQ' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StrengthFactorQ



'''_3797.py

HypoidGearSetPowerFlow
'''


from typing import List

from mastapy.system_model.part_model.gears import _2242
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6591
from mastapy.gears.rating.hypoid import _405
from mastapy.system_model.analyses_and_results.power_flows import _3796, _3795, _3738
from mastapy._internal.python_net import python_net_import

_HYPOID_GEAR_SET_POWER_FLOW = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows', 'HypoidGearSetPowerFlow')


__docformat__ = 'restructuredtext en'
__all__ = ('HypoidGearSetPowerFlow',)


class HypoidGearSetPowerFlow(_3738.AGMAGleasonConicalGearSetPowerFlow):
    '''HypoidGearSetPowerFlow

    This is a mastapy class.
    '''

    TYPE = _HYPOID_GEAR_SET_POWER_FLOW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'HypoidGearSetPowerFlow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2242.HypoidGearSet':
        '''HypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2242.HypoidGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6591.HypoidGearSetLoadCase':
        '''HypoidGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6591.HypoidGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def rating(self) -> '_405.HypoidGearSetRating':
        '''HypoidGearSetRating: 'Rating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_405.HypoidGearSetRating)(self.wrapped.Rating) if self.wrapped.Rating else None

    @property
    def component_detailed_analysis(self) -> '_405.HypoidGearSetRating':
        '''HypoidGearSetRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_405.HypoidGearSetRating)(self.wrapped.ComponentDetailedAnalysis) if self.wrapped.ComponentDetailedAnalysis else None

    @property
    def gears_power_flow(self) -> 'List[_3796.HypoidGearPowerFlow]':
        '''List[HypoidGearPowerFlow]: 'GearsPowerFlow' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearsPowerFlow, constructor.new(_3796.HypoidGearPowerFlow))
        return value

    @property
    def hypoid_gears_power_flow(self) -> 'List[_3796.HypoidGearPowerFlow]':
        '''List[HypoidGearPowerFlow]: 'HypoidGearsPowerFlow' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidGearsPowerFlow, constructor.new(_3796.HypoidGearPowerFlow))
        return value

    @property
    def meshes_power_flow(self) -> 'List[_3795.HypoidGearMeshPowerFlow]':
        '''List[HypoidGearMeshPowerFlow]: 'MeshesPowerFlow' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshesPowerFlow, constructor.new(_3795.HypoidGearMeshPowerFlow))
        return value

    @property
    def hypoid_meshes_power_flow(self) -> 'List[_3795.HypoidGearMeshPowerFlow]':
        '''List[HypoidGearMeshPowerFlow]: 'HypoidMeshesPowerFlow' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidMeshesPowerFlow, constructor.new(_3795.HypoidGearMeshPowerFlow))
        return value



'''_1090.py

CutterBladeType
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_CUTTER_BLADE_TYPE = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical', 'CutterBladeType')


__docformat__ = 'restructuredtext en'
__all__ = ('CutterBladeType',)


class CutterBladeType(Enum):
    '''CutterBladeType

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _CUTTER_BLADE_TYPE

    __hash__ = None

    STRAIGHT = 0
    CIRCULAR_ARC = 1
    PARABOLIC = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


CutterBladeType.__setattr__ = __enum_setattr
CutterBladeType.__delattr__ = __enum_delattr



'''_1347.py

GriddedSurfaceAccessor
'''


from typing import List

from mastapy.math_utility import _1296
from mastapy._internal import constructor, conversion
from mastapy._internal.python_net import python_net_import
from mastapy import _0

_ARRAY = python_net_import('System', 'Array')
_GRIDDED_SURFACE_ACCESSOR = python_net_import('SMT.MastaAPI.MathUtility.MeasuredData', 'GriddedSurfaceAccessor')


__docformat__ = 'restructuredtext en'
__all__ = ('GriddedSurfaceAccessor',)


class GriddedSurfaceAccessor(_0.APIBase):
    '''GriddedSurfaceAccessor

    This is a mastapy class.
    '''

    TYPE = _GRIDDED_SURFACE_ACCESSOR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GriddedSurfaceAccessor.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    def get_gridded_surface(self) -> '_1296.GriddedSurface':
        ''' 'GetGriddedSurface' is the original name of this method.

        Returns:
            mastapy.math_utility.GriddedSurface
        '''

        method_result = self.wrapped.GetGriddedSurface()
        return constructor.new_override(method_result.__class__)(method_result) if method_result else None

    def create_new_from_gridded_surface(self, grid: '_1296.GriddedSurface') -> 'GriddedSurfaceAccessor':
        ''' 'CreateNewFromGriddedSurface' is the original name of this method.

        Args:
            grid (mastapy.math_utility.GriddedSurface)

        Returns:
            mastapy.math_utility.measured_data.GriddedSurfaceAccessor
        '''

        method_result = self.wrapped.CreateNewFromGriddedSurface(grid.wrapped if grid else None)
        return constructor.new_override(method_result.__class__)(method_result) if method_result else None

    def create_new_from_gridded_data(self, x_values: 'List[float]', y_values: 'List[float]') -> 'GriddedSurfaceAccessor':
        ''' 'CreateNewFromGriddedData' is the original name of this method.

        Args:
            x_values (List[float])
            y_values (List[float])

        Returns:
            mastapy.math_utility.measured_data.GriddedSurfaceAccessor
        '''

        x_values = conversion.mp_to_pn_array_float(x_values)
        y_values = conversion.mp_to_pn_array_float(y_values)
        method_result = self.wrapped.CreateNewFromGriddedData(x_values, y_values)
        return constructor.new_override(method_result.__class__)(method_result) if method_result else None



'''_1412.py

ForcePerUnitLength
'''


from mastapy.utility.units_and_measurements import _1380
from mastapy._internal.python_net import python_net_import

_FORCE_PER_UNIT_LENGTH = python_net_import('SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements', 'ForcePerUnitLength')


__docformat__ = 'restructuredtext en'
__all__ = ('ForcePerUnitLength',)


class ForcePerUnitLength(_1380.MeasurementBase):
    '''ForcePerUnitLength

    This is a mastapy class.
    '''

    TYPE = _FORCE_PER_UNIT_LENGTH

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ForcePerUnitLength.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_7235.py

TimeSeriesLoadAnalysisCase
'''


from mastapy.system_model.analyses_and_results.static_loads import _6487
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.analysis_cases import _7219
from mastapy._internal.python_net import python_net_import

_TIME_SERIES_LOAD_ANALYSIS_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AnalysisCases', 'TimeSeriesLoadAnalysisCase')


__docformat__ = 'restructuredtext en'
__all__ = ('TimeSeriesLoadAnalysisCase',)


class TimeSeriesLoadAnalysisCase(_7219.AnalysisCase):
    '''TimeSeriesLoadAnalysisCase

    This is a mastapy class.
    '''

    TYPE = _TIME_SERIES_LOAD_ANALYSIS_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'TimeSeriesLoadAnalysisCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def load_case(self) -> '_6487.TimeSeriesLoadCase':
        '''TimeSeriesLoadCase: 'LoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6487.TimeSeriesLoadCase)(self.wrapped.LoadCase) if self.wrapped.LoadCase else None



'''_1212.py

SAESplineJointRating
'''


from mastapy._internal import constructor
from mastapy.detailed_rigid_connectors.splines.ratings import _1214
from mastapy._internal.python_net import python_net_import

_SAE_SPLINE_JOINT_RATING = python_net_import('SMT.MastaAPI.DetailedRigidConnectors.Splines.Ratings', 'SAESplineJointRating')


__docformat__ = 'restructuredtext en'
__all__ = ('SAESplineJointRating',)


class SAESplineJointRating(_1214.SplineJointRating):
    '''SAESplineJointRating

    This is a mastapy class.
    '''

    TYPE = _SAE_SPLINE_JOINT_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SAESplineJointRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name

    @property
    def fatigue_life_factor(self) -> 'float':
        '''float: 'FatigueLifeFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FatigueLifeFactor

    @property
    def wear_life_factor(self) -> 'float':
        '''float: 'WearLifeFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WearLifeFactor

    @property
    def misalignment_factor(self) -> 'float':
        '''float: 'MisalignmentFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MisalignmentFactor

    @property
    def over_load_factor(self) -> 'float':
        '''float: 'OverLoadFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OverLoadFactor

    @property
    def allowable_compressive_stress(self) -> 'float':
        '''float: 'AllowableCompressiveStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AllowableCompressiveStress

    @property
    def active_contact_height(self) -> 'float':
        '''float: 'ActiveContactHeight' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ActiveContactHeight

    @property
    def calculated_compressive_stress(self) -> 'float':
        '''float: 'CalculatedCompressiveStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CalculatedCompressiveStress

    @property
    def allowable_shear_stress(self) -> 'float':
        '''float: 'AllowableShearStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AllowableShearStress

    @property
    def calculated_maximum_tooth_shearing_stress(self) -> 'float':
        '''float: 'CalculatedMaximumToothShearingStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CalculatedMaximumToothShearingStress

    @property
    def maximum_allowable_tensile_stress(self) -> 'float':
        '''float: 'MaximumAllowableTensileStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumAllowableTensileStress

    @property
    def internal_hoop_stress(self) -> 'float':
        '''float: 'InternalHoopStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InternalHoopStress

    @property
    def safety_factor_for_equivalent_root_stress(self) -> 'float':
        '''float: 'SafetyFactorForEquivalentRootStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactorForEquivalentRootStress

    @property
    def fatigue_damage_for_equivalent_root_stress(self) -> 'float':
        '''float: 'FatigueDamageForEquivalentRootStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FatigueDamageForEquivalentRootStress

    @property
    def safety_factor_for_compressive_stress(self) -> 'float':
        '''float: 'SafetyFactorForCompressiveStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactorForCompressiveStress

    @property
    def fatigue_damage_for_compressive_stress(self) -> 'float':
        '''float: 'FatigueDamageForCompressiveStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FatigueDamageForCompressiveStress

    @property
    def safety_factor_for_tooth_shearing_stress(self) -> 'float':
        '''float: 'SafetyFactorForToothShearingStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SafetyFactorForToothShearingStress

    @property
    def fatigue_damage_for_tooth_shearing_stress(self) -> 'float':
        '''float: 'FatigueDamageForToothShearingStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FatigueDamageForToothShearingStress



'''_164.py

FEModelSetupViewType
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_FE_MODEL_SETUP_VIEW_TYPE = python_net_import('SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses', 'FEModelSetupViewType')


__docformat__ = 'restructuredtext en'
__all__ = ('FEModelSetupViewType',)


class FEModelSetupViewType(Enum):
    '''FEModelSetupViewType

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _FE_MODEL_SETUP_VIEW_TYPE

    __hash__ = None

    CURRENT_SETUP = 0
    REDUCTION_RESULT = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


FEModelSetupViewType.__setattr__ = __enum_setattr
FEModelSetupViewType.__delattr__ = __enum_delattr



'''_3804.py

KlingelnbergCycloPalloidHypoidGearSetPowerFlow
'''


from typing import List

from mastapy.system_model.part_model.gears import _2246
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6601
from mastapy.gears.rating.klingelnberg_hypoid import _375
from mastapy.system_model.analyses_and_results.power_flows import _3803, _3802, _3801
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET_POWER_FLOW = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows', 'KlingelnbergCycloPalloidHypoidGearSetPowerFlow')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidHypoidGearSetPowerFlow',)


class KlingelnbergCycloPalloidHypoidGearSetPowerFlow(_3801.KlingelnbergCycloPalloidConicalGearSetPowerFlow):
    '''KlingelnbergCycloPalloidHypoidGearSetPowerFlow

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SET_POWER_FLOW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidHypoidGearSetPowerFlow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def assembly_design(self) -> '_2246.KlingelnbergCycloPalloidHypoidGearSet':
        '''KlingelnbergCycloPalloidHypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2246.KlingelnbergCycloPalloidHypoidGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6601.KlingelnbergCycloPalloidHypoidGearSetLoadCase':
        '''KlingelnbergCycloPalloidHypoidGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6601.KlingelnbergCycloPalloidHypoidGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def rating(self) -> '_375.KlingelnbergCycloPalloidHypoidGearSetRating':
        '''KlingelnbergCycloPalloidHypoidGearSetRating: 'Rating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_375.KlingelnbergCycloPalloidHypoidGearSetRating)(self.wrapped.Rating) if self.wrapped.Rating else None

    @property
    def component_detailed_analysis(self) -> '_375.KlingelnbergCycloPalloidHypoidGearSetRating':
        '''KlingelnbergCycloPalloidHypoidGearSetRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_375.KlingelnbergCycloPalloidHypoidGearSetRating)(self.wrapped.ComponentDetailedAnalysis) if self.wrapped.ComponentDetailedAnalysis else None

    @property
    def gears_power_flow(self) -> 'List[_3803.KlingelnbergCycloPalloidHypoidGearPowerFlow]':
        '''List[KlingelnbergCycloPalloidHypoidGearPowerFlow]: 'GearsPowerFlow' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearsPowerFlow, constructor.new(_3803.KlingelnbergCycloPalloidHypoidGearPowerFlow))
        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gears_power_flow(self) -> 'List[_3803.KlingelnbergCycloPalloidHypoidGearPowerFlow]':
        '''List[KlingelnbergCycloPalloidHypoidGearPowerFlow]: 'KlingelnbergCycloPalloidHypoidGearsPowerFlow' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidHypoidGearsPowerFlow, constructor.new(_3803.KlingelnbergCycloPalloidHypoidGearPowerFlow))
        return value

    @property
    def meshes_power_flow(self) -> 'List[_3802.KlingelnbergCycloPalloidHypoidGearMeshPowerFlow]':
        '''List[KlingelnbergCycloPalloidHypoidGearMeshPowerFlow]: 'MeshesPowerFlow' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshesPowerFlow, constructor.new(_3802.KlingelnbergCycloPalloidHypoidGearMeshPowerFlow))
        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_meshes_power_flow(self) -> 'List[_3802.KlingelnbergCycloPalloidHypoidGearMeshPowerFlow]':
        '''List[KlingelnbergCycloPalloidHypoidGearMeshPowerFlow]: 'KlingelnbergCycloPalloidHypoidMeshesPowerFlow' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.KlingelnbergCycloPalloidHypoidMeshesPowerFlow, constructor.new(_3802.KlingelnbergCycloPalloidHypoidGearMeshPowerFlow))
        return value



'''_6751.py

FEPartAdvancedTimeSteppingAnalysisForModulation
'''


from typing import List

from mastapy.system_model.analyses_and_results.harmonic_analyses import _5712
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.harmonic_analyses.reportable_property_results import _5800
from mastapy.system_model.part_model import _2161
from mastapy.system_model.analyses_and_results.static_loads import _6569
from mastapy.system_model.analyses_and_results.system_deflections import _2459
from mastapy.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import _6693
from mastapy._internal.python_net import python_net_import

_FE_PART_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation', 'FEPartAdvancedTimeSteppingAnalysisForModulation')


__docformat__ = 'restructuredtext en'
__all__ = ('FEPartAdvancedTimeSteppingAnalysisForModulation',)


class FEPartAdvancedTimeSteppingAnalysisForModulation(_6693.AbstractShaftOrHousingAdvancedTimeSteppingAnalysisForModulation):
    '''FEPartAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    '''

    TYPE = _FE_PART_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FEPartAdvancedTimeSteppingAnalysisForModulation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def export(self) -> '_5712.HarmonicAnalysisFEExportOptions':
        '''HarmonicAnalysisFEExportOptions: 'Export' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_5712.HarmonicAnalysisFEExportOptions)(self.wrapped.Export) if self.wrapped.Export else None

    @property
    def results(self) -> '_5800.FEPartHarmonicAnalysisResultsPropertyAccessor':
        '''FEPartHarmonicAnalysisResultsPropertyAccessor: 'Results' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_5800.FEPartHarmonicAnalysisResultsPropertyAccessor)(self.wrapped.Results) if self.wrapped.Results else None

    @property
    def component_design(self) -> '_2161.FEPart':
        '''FEPart: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2161.FEPart)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6569.FEPartLoadCase':
        '''FEPartLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6569.FEPartLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def system_deflection_results(self) -> '_2459.FEPartSystemDeflection':
        '''FEPartSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2459.FEPartSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def planetaries(self) -> 'List[FEPartAdvancedTimeSteppingAnalysisForModulation]':
        '''List[FEPartAdvancedTimeSteppingAnalysisForModulation]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(FEPartAdvancedTimeSteppingAnalysisForModulation))
        return value



'''_1358.py

EnvironmentSummary
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.utility import _1368, _1357
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_ENVIRONMENT_SUMMARY = python_net_import('SMT.MastaAPI.Utility', 'EnvironmentSummary')


__docformat__ = 'restructuredtext en'
__all__ = ('EnvironmentSummary',)


class EnvironmentSummary(_0.APIBase):
    '''EnvironmentSummary

    This is a mastapy class.
    '''

    TYPE = _ENVIRONMENT_SUMMARY

    __hash__ = None

    def __init__(self, instance_to_wrap: 'EnvironmentSummary.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def entry_assembly(self) -> 'str':
        '''str: 'EntryAssembly' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EntryAssembly

    @property
    def user_name(self) -> 'str':
        '''str: 'UserName' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.UserName

    @property
    def machine_name(self) -> 'str':
        '''str: 'MachineName' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MachineName

    @property
    def operating_system(self) -> 'str':
        '''str: 'OperatingSystem' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OperatingSystem

    @property
    def is_64_bit_operating_system(self) -> 'bool':
        '''bool: 'Is64BitOperatingSystem' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Is64BitOperatingSystem

    @property
    def current_net_version(self) -> 'str':
        '''str: 'CurrentNETVersion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CurrentNETVersion

    @property
    def prerequisites(self) -> 'str':
        '''str: 'Prerequisites' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Prerequisites

    @property
    def processor(self) -> 'str':
        '''str: 'Processor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Processor

    @property
    def ram(self) -> 'str':
        '''str: 'RAM' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RAM

    @property
    def video_controller_in_use(self) -> 'str':
        '''str: 'VideoControllerInUse' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VideoControllerInUse

    @property
    def installed_video_controllers(self) -> 'str':
        '''str: 'InstalledVideoControllers' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.InstalledVideoControllers

    @property
    def open_gl_version(self) -> 'str':
        '''str: 'OpenGLVersion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OpenGLVersion

    @property
    def open_gl_vendor(self) -> 'str':
        '''str: 'OpenGLVendor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OpenGLVendor

    @property
    def open_gl_renderer(self) -> 'str':
        '''str: 'OpenGLRenderer' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OpenGLRenderer

    @property
    def process_render_mode(self) -> 'str':
        '''str: 'ProcessRenderMode' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ProcessRenderMode

    @property
    def current_culture_system_locale(self) -> 'str':
        '''str: 'CurrentCultureSystemLocale' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CurrentCultureSystemLocale

    @property
    def current_ui_culture_system_locale(self) -> 'str':
        '''str: 'CurrentUICultureSystemLocale' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CurrentUICultureSystemLocale

    @property
    def licence_key(self) -> 'str':
        '''str: 'LicenceKey' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LicenceKey

    @property
    def core_feature_code_in_use(self) -> 'str':
        '''str: 'CoreFeatureCodeInUse' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CoreFeatureCodeInUse

    @property
    def core_feature_expiry(self) -> 'str':
        '''str: 'CoreFeatureExpiry' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CoreFeatureExpiry

    @property
    def masta_version(self) -> 'str':
        '''str: 'MASTAVersion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MASTAVersion

    @property
    def build_date(self) -> 'str':
        '''str: 'BuildDate' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BuildDate

    @property
    def build_date_and_age(self) -> 'str':
        '''str: 'BuildDateAndAge' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BuildDateAndAge

    @property
    def date_time_iso8601(self) -> 'str':
        '''str: 'DateTimeISO8601' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DateTimeISO8601

    @property
    def date_time_local_format(self) -> 'str':
        '''str: 'DateTimeLocalFormat' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DateTimeLocalFormat

    @property
    def start_date_time_and_age(self) -> 'str':
        '''str: 'StartDateTimeAndAge' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StartDateTimeAndAge

    @property
    def executable_directory(self) -> 'str':
        '''str: 'ExecutableDirectory' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ExecutableDirectory

    @property
    def executable_directory_is_network_path(self) -> 'bool':
        '''bool: 'ExecutableDirectoryIsNetworkPath' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ExecutableDirectoryIsNetworkPath

    @property
    def dispatcher_information(self) -> 'str':
        '''str: 'DispatcherInformation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DispatcherInformation

    @property
    def remote_desktop_information(self) -> 'str':
        '''str: 'RemoteDesktopInformation' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RemoteDesktopInformation

    @property
    def current_culture(self) -> '_1368.NumberFormatInfoSummary':
        '''NumberFormatInfoSummary: 'CurrentCulture' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1368.NumberFormatInfoSummary)(self.wrapped.CurrentCulture) if self.wrapped.CurrentCulture else None

    @property
    def dispatchers(self) -> 'List[_1357.DispatcherHelper]':
        '''List[DispatcherHelper]: 'Dispatchers' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Dispatchers, constructor.new(_1357.DispatcherHelper))
        return value

    @property
    def report_names(self) -> 'List[str]':
        '''List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ReportNames, str)
        return value

    def __copy__(self):
        ''' 'Copy' is the original name of this method.'''

        self.wrapped.Copy()

    def __deepcopy__(self, memo):
        ''' 'Copy' is the original name of this method.'''

        self.wrapped.Copy()

    def output_default_report_to(self, file_path: 'str'):
        ''' 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else None)

    def get_default_report_with_encoded_images(self) -> 'str':
        ''' 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        ''' 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else None)

    def output_active_report_as_text_to(self, file_path: 'str'):
        ''' 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else None)

    def get_active_report_with_encoded_images(self) -> 'str':
        ''' 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else None, file_path if file_path else None)

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        ''' 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        '''

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else None)
        return method_result



'''_5760.py

SpringDamperHalfHarmonicAnalysis
'''


from mastapy.system_model.part_model.couplings import _2308
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6643
from mastapy.system_model.analyses_and_results.system_deflections import _2513
from mastapy.system_model.analyses_and_results.harmonic_analyses import _5669
from mastapy._internal.python_net import python_net_import

_SPRING_DAMPER_HALF_HARMONIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses', 'SpringDamperHalfHarmonicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('SpringDamperHalfHarmonicAnalysis',)


class SpringDamperHalfHarmonicAnalysis(_5669.CouplingHalfHarmonicAnalysis):
    '''SpringDamperHalfHarmonicAnalysis

    This is a mastapy class.
    '''

    TYPE = _SPRING_DAMPER_HALF_HARMONIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpringDamperHalfHarmonicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2308.SpringDamperHalf':
        '''SpringDamperHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2308.SpringDamperHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6643.SpringDamperHalfLoadCase':
        '''SpringDamperHalfLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6643.SpringDamperHalfLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def system_deflection_results(self) -> '_2513.SpringDamperHalfSystemDeflection':
        '''SpringDamperHalfSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2513.SpringDamperHalfSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None



'''_1927.py

MeshStiffnessModel
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_MESH_STIFFNESS_MODEL = python_net_import('SMT.MastaAPI.SystemModel', 'MeshStiffnessModel')


__docformat__ = 'restructuredtext en'
__all__ = ('MeshStiffnessModel',)


class MeshStiffnessModel(Enum):
    '''MeshStiffnessModel

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _MESH_STIFFNESS_MODEL

    __hash__ = None

    CONSTANT_IN_LOA = 0
    ADVANCED_SYSTEM_DEFLECTION = 1
    ISO_SIMPLE_CONTINUOUS_MODEL = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


MeshStiffnessModel.__setattr__ = __enum_setattr
MeshStiffnessModel.__delattr__ = __enum_delattr



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1223 import KeywayHalfRating
    from ._1224 import KeywayRating



'''_93.py

SinglePointSelectionMethod
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_SINGLE_POINT_SELECTION_METHOD = python_net_import('SMT.MastaAPI.NodalAnalysis.VaryingInputComponents', 'SinglePointSelectionMethod')


__docformat__ = 'restructuredtext en'
__all__ = ('SinglePointSelectionMethod',)


class SinglePointSelectionMethod(Enum):
    '''SinglePointSelectionMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _SINGLE_POINT_SELECTION_METHOD

    __hash__ = None

    CURRENT_TIME = 0
    MEAN_VALUE = 1


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


SinglePointSelectionMethod.__setattr__ = __enum_setattr
SinglePointSelectionMethod.__delattr__ = __enum_delattr
